##########################
Tables (:mod:`gwpy.table`)
##########################

.. automodule:: gwpy.table

.. seealso::

    - **User Guide**: :doc:`/table/index`
    - **Examples**: :doc:`/examples/table/index`

.. automodapi:: gwpy.table
    :include-all-objects:
    :no-heading:
    :no-main-docstr:
